# translatemib.mak
#  RBLandau 20070909
# Translate the XML group files into MIB fragments using Xalan.
# Then assemble the fragments into a real MIB using Perl.  

#=======================================================
# D i r e c t o r y   l a y o u t 
#=======================================================
# NOTE: PERL refers to ActivePerl, which runs better on Windows
# because it tolerates \r\n and \n line endings.  
SRC = ..
XSL = .
DST = ./mib
PERL = c:/perl/bin
MIBSRC = ../../mib

# Command to run Xalan to do the translation
PGMDIR = /cygdrive/c
PGM = $(PGMDIR)/run_xalan.sh

#=======================================================
#  L a t e s t   V e r s i o n s 
#=======================================================
# Latest versions of the XML groups
#=======================================================
# The target forceupdateversions gets the latest 
# version numbers from the SRC directory.  
include xmlfileversions_out.txt
#=======================================================

#=======================================================
# Latest versions of the XSL translation and other programs
#=======================================================
# These version numbers must be maintained manually, sorry.  
VER_TABLES = 11
VER_PROPS = 22
VER_ENUMS = 06
VER_ASSEMBLE = 01
VER_SKELETONBASIC = 02
VER_GETVERSIONNUMBERS = 03
VER_WRITEGROUPINCLUDES = 03
VER_FIXUPGROUPNUMBERS = 01
VER_FIXUPREMOVEDUPOIDS = 02
VER_FIXUPREMOVEBLANKLINES = 01
VER_FIXUPWRAPDESCRIPTIONS = 03
VER_FIXUPREMOVEBLANKUNITS = 00
VER_CHECKFINDLONGNAMES = 02

# Now paste program names and versions together into a full filename
TABLES = tables$(VER_TABLES).xsl
PROPS = props$(VER_PROPS).xsl
ENUMS = enumtc$(VER_ENUMS).xsl
ASSEMBLE = assemblefiles$(VER_ASSEMBLE).pl
WRITEGROUPINCLUDES = skel-writegroupincludes-$(VER_WRITEGROUPINCLUDES).pl
GETVERSIONNUMBERS = skel-getversionnumbers$(VER_GETVERSIONNUMBERS).pl
FIXUPGROUPNUMBERS = fixup-insertgroupnumbers-$(VER_FIXUPGROUPNUMBERS).pl
FIXUPREMOVEDUPOIDS = fixup-removeduplicateoids-$(VER_FIXUPREMOVEDUPOIDS).pl
FIXUPREMOVEBLANKLINES = fixup-removeblanklines-$(VER_FIXUPREMOVEBLANKLINES).pl
FIXUPWRAPDESCRIPTIONS = fixup-wrapdescriptions-$(VER_FIXUPWRAPDESCRIPTIONS).pl 
FIXUPREMOVEBLANKUNITS = fixup-removeblankunits-$(VER_FIXUPREMOVEBLANKUNITS).pl
CHECKFINDLONGNAMES  = check-findlongnames-$(VER_CHECKFINDLONGNAMES).pl

#=======================================================
#  T a r g e t s 
#=======================================================
# Really, really do absolutely everything.  
all : updateversions compile target_finalmib target_checkmib

# Do all the XSL compilations.
compile : \
        target_translators  \
        target_alert        \
        target_button       \
        target_displaycapability    \
        target_fan          \
        target_filter       \
        target_general      \
        target_connector    \
        target_interlock    \
        target_lightsource  \
        target_localecharset    \
        target_localelanguage   \
        target_powerstate   \
        target_controller   \
        target_audio        \
        target_displaysetting\
        target_thermalsensor\
        target_thermalswitch\
        target_moveall      \
#

#=======================================================
#  M o v e   f i l e s 
#=======================================================
# Target for moving all the necessary files to the DST directory.
# Lose the version numbers in the filenames, which are hard to deal with.
target_moveall : \
                $(DST)/Alert.xml            \
                $(DST)/Button.xml           \
                $(DST)/DisplayCapability.xml\
                $(DST)/Fan.xml              \
                $(DST)/General.xml          \
                $(DST)/Connector.xml        \
                $(DST)/Interlock.xml        \
                $(DST)/LightSource.xml      \
                $(DST)/LocaleCharset.xml    \
                $(DST)/LocaleLanguage.xml   \
                $(DST)/PowerState.xml       \
                $(DST)/Controller.xml       \
                $(DST)/Audio.xml            \
                $(DST)/DisplaySetting.xml   \
                $(DST)/Filter.xml           \
                $(DST)/ThermalSensor.xml    \
                $(DST)/ThermalSwitch.xml    

$(DST)/Alert.xml : $(SRC)/Alert_v$(VER_ALERT).xml
	cp $(SRC)/Alert_v$(VER_ALERT).xml $(DST)/Alert.xml
$(DST)/Button.xml : $(SRC)/Button_v$(VER_BUTTON).xml
	cp $(SRC)/Button_v$(VER_BUTTON).xml $(DST)/Button.xml
$(DST)/DisplayCapability.xml : $(SRC)/DisplayCapability_v$(VER_DISPLAYCAPABILITY).xml
	cp $(SRC)/DisplayCapability_v$(VER_DISPLAYCAPABILITY).xml  $(DST)/DisplayCapability.xml
$(DST)/General.xml : $(SRC)/General_v$(VER_GENERAL).xml
	cp $(SRC)/General_v$(VER_GENERAL).xml  $(DST)/General.xml
$(DST)/Connector.xml : $(SRC)/Connector_v$(VER_CONNECTOR).xml
	cp $(SRC)/Connector_v$(VER_CONNECTOR).xml  $(DST)/Connector.xml
$(DST)/Interlock.xml : $(SRC)/Interlock_v$(VER_INTERLOCK).xml
	cp $(SRC)/Interlock_v$(VER_INTERLOCK).xml  $(DST)/Interlock.xml
$(DST)/LightSource.xml : $(SRC)/LightSource_v$(VER_LIGHTSOURCE).xml
	cp $(SRC)/LightSource_v$(VER_LIGHTSOURCE).xml  $(DST)/LightSource.xml
$(DST)/LocaleCharset.xml : $(SRC)/LocaleCharset_v$(VER_LOCALECHARSET).xml
	cp $(SRC)/LocaleCharset_v$(VER_LOCALECHARSET).xml  $(DST)/LocaleCharset.xml
$(DST)/LocaleLanguage.xml : $(SRC)/LocaleLanguage_v$(VER_LOCALELANGUAGE).xml
	cp $(SRC)/LocaleLanguage_v$(VER_LOCALELANGUAGE).xml  $(DST)/LocaleLanguage.xml
$(DST)/PowerState.xml : $(SRC)/PowerState_v$(VER_POWERSTATE).xml
	cp $(SRC)/PowerState_v$(VER_POWERSTATE).xml $(DST)/PowerState.xml
$(DST)/Controller.xml : $(SRC)/Controller_v$(VER_CONTROLLER).xml
	cp $(SRC)/Controller_v$(VER_CONTROLLER).xml  $(DST)/Controller.xml
$(DST)/Fan.xml : $(SRC)/Fan_v$(VER_FAN).xml
	cp $(SRC)/Fan_v$(VER_FAN).xml $(DST)/Fan.xml
$(DST)/Audio.xml : $(SRC)/Audio_v$(VER_AUDIO).xml
	cp $(SRC)/Audio_v$(VER_AUDIO).xml $(DST)/Audio.xml
$(DST)/DisplaySetting.xml : $(SRC)/DisplaySetting_v$(VER_DISPLAYSETTING).xml
	cp $(SRC)/DisplaySetting_v$(VER_DISPLAYSETTING).xml $(DST)/DisplaySetting.xml
$(DST)/Filter.xml : $(SRC)/Filter_v$(VER_FILTER).xml
	cp $(SRC)/Filter_v$(VER_FILTER).xml $(DST)/Filter.xml
$(DST)/ThermalSensor.xml : $(SRC)/ThermalSensor_v$(VER_THERMALSENSOR).xml
	cp $(SRC)/ThermalSensor_v$(VER_THERMALSENSOR).xml $(DST)/ThermalSensor.xml
$(DST)/ThermalSwitch.xml : $(SRC)/ThermalSwitch_v$(VER_THERMALSWITCH).xml
	cp $(SRC)/ThermalSwitch_v$(VER_THERMALSWITCH).xml $(DST)/ThermalSwitch.xml

#=======================================================
#  T r a n s l a t e   X M L   t o   M I B 
#=======================================================
# A target for the XSL files themselves
target_translators : $(TABLES) $(PROPS) $(ENUMS) 

# Targets for the individual groups

# A l e r t 
target_alert :      $(DST)/alert.tables.mib    \
                    $(DST)/alert.props.mib     \
                    $(DST)/alert.enums.mib     \
                    target_translators
$(DST)/alert.tables.mib : $(DST)/Alert.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/alert.tables.mib
$(DST)/alert.props.mib : $(DST)/Alert.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/alert.props.mib
$(DST)/alert.enums.mib : $(DST)/Alert.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/alert.enums.mib

# B u t t o n
target_button :     $(DST)/button.tables.mib    \
                    $(DST)/button.props.mib     \
                    $(DST)/button.enums.mib     \
                    target_translators
$(DST)/button.tables.mib : $(DST)/Button.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/button.tables.mib
$(DST)/button.props.mib : $(DST)/Button.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/button.props.mib
$(DST)/button.enums.mib : $(DST)/Button.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/button.enums.mib

# C o n n e c t o r 
target_connector :  $(DST)/connector.tables.mib \
                    $(DST)/connector.props.mib  \
                    $(DST)/connector.enums.mib  \
                    target_translators
$(DST)/connector.tables.mib : $(DST)/Connector.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/connector.tables.mib
$(DST)/connector.props.mib : $(DST)/Connector.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/connector.props.mib
$(DST)/connector.enums.mib : $(DST)/Connector.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/connector.enums.mib

# D i s p l a y C a p a b i l i t y 
target_displaycapability :  $(DST)/displaycapability.tables.mib \
                            $(DST)/displaycapability.props.mib  \
                            $(DST)/displaycapability.enums.mib  \
                            target_translators
$(DST)/displaycapability.tables.mib : $(DST)/DisplayCapability.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/displaycapability.tables.mib
$(DST)/displaycapability.props.mib : $(DST)/DisplayCapability.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/displaycapability.props.mib
$(DST)/displaycapability.enums.mib : $(DST)/DisplayCapability.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/displaycapability.enums.mib

# G e n e r a l  
target_general :    $(DST)/general.tables.mib    \
                    $(DST)/general.props.mib     \
                    $(DST)/general.enums.mib     \
                    target_translators
$(DST)/general.tables.mib : $(DST)/General.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/general.tables.mib
$(DST)/general.props.mib : $(DST)/General.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/general.props.mib
$(DST)/general.enums.mib : $(DST)/General.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/general.enums.mib

# I n t e r l o c k 
target_interlock :  $(DST)/interlock.tables.mib \
                    $(DST)/interlock.props.mib  \
                    $(DST)/interlock.enums.mib  \
                    target_translators
$(DST)/interlock.tables.mib : $(DST)/Interlock.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/interlock.tables.mib
$(DST)/interlock.props.mib : $(DST)/Interlock.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/interlock.props.mib
$(DST)/interlock.enums.mib : $(DST)/Interlock.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/interlock.enums.mib

# L i g h t S o u r c e 
target_lightsource :  $(DST)/lightsource.tables.mib \
                      $(DST)/lightsource.props.mib  \
                      $(DST)/lightsource.enums.mib  \
                      target_translators
$(DST)/lightsource.tables.mib : $(DST)/LightSource.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/lightsource.tables.mib
$(DST)/lightsource.props.mib : $(DST)/LightSource.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/lightsource.props.mib
$(DST)/lightsource.enums.mib : $(DST)/LightSource.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/lightsource.enums.mib

# L o c a l e C h a r s e t 
target_localecharset :  $(DST)/localecharset.tables.mib \
                       $(DST)/localecharset.props.mib  \
                       $(DST)/localecharset.enums.mib  \
                       target_translators
$(DST)/localecharset.tables.mib : $(DST)/LocaleCharset.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/localecharset.tables.mib
$(DST)/localecharset.props.mib : $(DST)/LocaleCharset.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/localecharset.props.mib
$(DST)/localecharset.enums.mib : $(DST)/LocaleCharset.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/localecharset.enums.mib

# L o c a l e L a n g u a g e 
target_localelanguage :  $(DST)/localelanguage.tables.mib \
                       $(DST)/localelanguage.props.mib  \
                       $(DST)/localelanguage.enums.mib  \
                       target_translators
$(DST)/localelanguage.tables.mib : $(DST)/LocaleLanguage.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/localelanguage.tables.mib
$(DST)/localelanguage.props.mib : $(DST)/LocaleLanguage.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/localelanguage.props.mib
$(DST)/localelanguage.enums.mib : $(DST)/LocaleLanguage.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/localelanguage.enums.mib

# P o w e r S t a t e 
target_powerstate :     $(DST)/powerstate.tables.mib \
                        $(DST)/powerstate.props.mib  \
                        $(DST)/powerstate.enums.mib  \
                        target_translators
$(DST)/powerstate.tables.mib : $(DST)/PowerState.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/powerstate.tables.mib
$(DST)/powerstate.props.mib : $(DST)/PowerState.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/powerstate.props.mib
$(DST)/powerstate.enums.mib : $(DST)/PowerState.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/powerstate.enums.mib

# C o n t r o l l e r 
target_controller :     $(DST)/controller.tables.mib \
                        $(DST)/controller.props.mib  \
                        $(DST)/controller.enums.mib  \
                        target_translators
$(DST)/controller.tables.mib : $(DST)/Controller.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/controller.tables.mib
$(DST)/controller.props.mib : $(DST)/Controller.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/controller.props.mib
$(DST)/controller.enums.mib : $(DST)/Controller.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/controller.enums.mib

# F a n 
target_fan :            $(DST)/fan.tables.mib \
                        $(DST)/fan.props.mib  \
                        $(DST)/fan.enums.mib  \
                        target_translators
$(DST)/fan.tables.mib : $(DST)/Fan.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/fan.tables.mib
$(DST)/fan.props.mib : $(DST)/Fan.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/fan.props.mib
$(DST)/fan.enums.mib : $(DST)/Fan.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/fan.enums.mib

# F i l t e r
target_filter :     $(DST)/filter.tables.mib    \
                    $(DST)/filter.props.mib     \
                    $(DST)/filter.enums.mib     \
                    target_translators
$(DST)/filter.tables.mib : $(DST)/Filter.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/filter.tables.mib
$(DST)/filter.props.mib : $(DST)/Filter.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/filter.props.mib
$(DST)/filter.enums.mib : $(DST)/Filter.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/filter.enums.mib

# A u d i o 
target_audio :     $(DST)/audio.tables.mib  \
                    $(DST)/audio.props.mib  \
                    $(DST)/audio.enums.mib  \
                    target_translators
$(DST)/audio.tables.mib : $(DST)/Audio.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/audio.tables.mib
$(DST)/audio.props.mib : $(DST)/Audio.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/audio.props.mib
$(DST)/audio.enums.mib : $(DST)/Audio.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/audio.enums.mib

# D i s p l a y S e t t i n g 
target_displaysetting :     $(DST)/displaysetting.tables.mib    \
                    $(DST)/displaysetting.props.mib     \
                    $(DST)/displaysetting.enums.mib     \
                    target_translators
$(DST)/displaysetting.tables.mib : $(DST)/DisplaySetting.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/displaysetting.tables.mib
$(DST)/displaysetting.props.mib : $(DST)/DisplaySetting.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/displaysetting.props.mib
$(DST)/displaysetting.enums.mib : $(DST)/DisplaySetting.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/displaysetting.enums.mib

# T h e r m a l S e n s o r 
target_thermalsensor :     $(DST)/thermalsensor.tables.mib    \
                    $(DST)/thermalsensor.props.mib     \
                    $(DST)/thermalsensor.enums.mib     \
                    target_translators
$(DST)/thermalsensor.tables.mib : $(DST)/ThermalSensor.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/thermalsensor.tables.mib
$(DST)/thermalsensor.props.mib : $(DST)/ThermalSensor.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/thermalsensor.props.mib
$(DST)/thermalsensor.enums.mib : $(DST)/ThermalSensor.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/thermalsensor.enums.mib

# T h e r m a l S w i t c h 
target_thermalswitch :     $(DST)/thermalswitch.tables.mib    \
                    $(DST)/thermalswitch.props.mib     \
                    $(DST)/thermalswitch.enums.mib     \
                    target_translators
$(DST)/thermalswitch.tables.mib : $(DST)/ThermalSwitch.xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/thermalswitch.tables.mib
$(DST)/thermalswitch.props.mib : $(DST)/ThermalSwitch.xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/thermalswitch.props.mib
$(DST)/thermalswitch.enums.mib : $(DST)/ThermalSwitch.xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/thermalswitch.enums.mib

#=======================================================
#  M a i n t e n a n c e   t a r g e t s 
#=======================================================

# Clean everything in destination.
.PHONY : clean
clean : cleanskeleton
	ls $(DST)
	rm -f $(DST)/*.tables.mib $(DST)/*.props.mib $(DST)/*.enums.mib
	rm -f $(DST)/skel*.mib
	rm -f $(DST)/*.xml
	touch $(DST)/zzzDELETEME.tables.mib
	touch $(DST)/zzzDELETEME.props.mib
	touch $(DST)/zzzDELETEME.enums.mib
	ls $(DST)

# Clean just the mib skeleton info in destination.  
.PHONY : cleanskeleton
cleanskeleton : 
	rm -f $(DST)/skel* $(DST)/skel*.*

# Print something maybe useful.  
.PHONY : info
info : help
.PHONY : help
help :
	@echo Makefile for Projector \& Display Management Working Group.
	@echo Translate property group definitions from XML to MIB fragments.
	@echo Version 17 2007/10/31
	@echo Targets:
	@echo all
	@echo list
	@echo listfull
	@echo clean
	@echo cleanskeleton
	@echo updateversions
	@echo forceupdateversions

# What's in the destination directory now?
.PHONY : list
list : 
	echo Output files:
	ls $(DST)

# Full listing with dates and sizes of destination directory.  
.PHONY : listfull
listfull : 
	echo Output files:
	ls -l $(DST)

#
.PHONY : forceupdateversions
forceupdateversions : 
	rm $(XSL)/xmlfileversions_out.txt
	$(PERL)/perl.exe $(XSL)/$(GETVERSIONNUMBERS)        \
	                $(XSL)/xmlfileversions_in.txt $(SRC) \
	                > $(XSL)/xmlfileversions_out.txt
	cat $(XSL)/xmlfileversions_out.txt

# Update the version numbers of the XML files to be used.
.PHONY : updateversions
updateversions : $(XSL)/xmlfileversions_out.txt

$(XSL)/xmlfileversions_out.txt : $(XSL)/xmlfileversions_in.txt   \
                                 $(XSL)/$(GETVERSIONNUMBERS)
	$(PERL)/perl.exe $(XSL)/$(GETVERSIONNUMBERS)        \
	                $(XSL)/xmlfileversions_in.txt $(SRC) \
	                > $(XSL)/xmlfileversions_out.txt

#=======================================================
#  A s s e m b l e   f r a g m e n t s   i n t o   M I B 
#=======================================================
# Now targets that paste the fragments into the MIB skeleton.

# Copy the basic skeleton and group number files to destination dir.  
$(DST)/skeleton-in-basic$(VER_SKELETONBASIC).mib :  \
        $(MIBSRC)/skeleton-in-basic$(VER_SKELETONBASIC).mib 
	cp $(MIBSRC)/skeleton-in-basic$(VER_SKELETONBASIC).mib  \
	   $(DST)/skeleton-in-basic$(VER_SKELETONBASIC).mib

$(DST)/skeleton-groupnumbers.txt :  $(MIBSRC)/skeleton-groupnumbers.txt
	cp $(MIBSRC)/skeleton-groupnumbers.txt $(DST)/skeleton-groupnumbers.txt

# Produce the #include directives for enums.
$(DST)/skeleton-groupsenums.txt :    $(DST)/skeleton-groupnumbers.txt    \
        $(XSL)/$(WRITEGROUPINCLUDES)
	$(PERL)/perl.exe $(XSL)/$(WRITEGROUPINCLUDES)   \
	                    $(DST)/skeleton-groupnumbers.txt enums   \
	                  > $(DST)/skeleton-groupsenums.txt

# Produce the #include directives for tables and props, interleaved.
$(DST)/skeleton-groupstablesprops.txt :  $(DST)/skeleton-groupnumbers.txt    \
        $(XSL)/$(WRITEGROUPINCLUDES)
	$(PERL)/perl.exe $(XSL)/$(WRITEGROUPINCLUDES)   \
	                    $(DST)/skeleton-groupnumbers.txt tables props   \
	                  > $(DST)/skeleton-groupstablesprops.txt

# Produce processable skeleton by inserting the #include directives
#  in the right order into the basic skeleton.
$(DST)/skeleton-in.mib :    $(DST)/skeleton-in-basic$(VER_SKELETONBASIC).mib    \
                            $(DST)/skeleton-groupsenums.txt         \
                            $(DST)/skeleton-groupstablesprops.txt   \
                            $(XSL)/$(ASSEMBLE)
	$(PERL)/perl.exe $(XSL)/$(ASSEMBLE)     \
                     $(DST)/skeleton-in-basic$(VER_SKELETONBASIC).mib   \
                     > $(DST)/skeleton-in.mib

# Produce full skeleton by filling in all enums, tables, props fragments.

$(DST)/skeleton-out.mib :   $(DST)/skeleton-in.mib  \
                            $(DST)/*.tables.mib     \
                            $(DST)/*.props.mib      \
                            $(DST)/*.enums.mib      \
                            $(XSL)/$(ASSEMBLE)  
	$(PERL)/perl.exe $(XSL)/$(ASSEMBLE)             \
                     $(DST)/skeleton-in.mib         \
                     > $(DST)/skeleton-out.mib

#=======================================================
# F i x u p s 
#=======================================================
# Produce the so-called final version of the MIB by applying 
# fixups to the full skeleton. 
target_finalmib :   $(DST)/skeleton-out.mib     \
                    $(DST)/skeleton-fixup1.mib  \
                    $(DST)/skeleton-fixup2.mib  \
                    $(DST)/skeleton-fixup3.mib  \
                    $(DST)/skeleton-fixup4.mib  \
                    $(DST)/skeleton-fixup5.mib  \
                    $(DST)/skeleton-final.mib

# Move whatever the last fixup file is to the really, really final file.
$(DST)/skeleton-final.mib : $(DST)/skeleton-fixup5.mib 
	cp $(DST)/skeleton-fixup5.mib $(DST)/skeleton-final.mib

# First fixup: insert group numbers into OBJECT IDENTIFIER statements.
$(DST)/skeleton-fixup1.mib :    $(DST)/skeleton-out.mib             \
                                $(DST)/skeleton-groupnumbers.txt    \
                                $(XSL)/$(FIXUPGROUPNUMBERS)         
	$(PERL)/perl.exe $(XSL)/$(FIXUPGROUPNUMBERS)     \
                     $(DST)/skeleton-groupnumbers.txt   \
                     $(DST)/skeleton-out.mib       \
                     > $(DST)/skeleton-fixup1.mib

# Second fixup: remove redundant group OID assignment statements,
# if they exist due to scalar and table properties both appearing
# a group.  
$(DST)/skeleton-fixup2.mib : $(DST)/skeleton-fixup1.mib \
                            $(XSL)/$(FIXUPREMOVEDUPOIDS)
	$(PERL)/perl.exe $(XSL)/$(FIXUPREMOVEDUPOIDS)     \
                     $(DST)/skeleton-fixup1.mib       \
                     > $(DST)/skeleton-fixup2.mib

# Third fixup: Compress multiple blank lines to one.
$(DST)/skeleton-fixup3.mib : $(DST)/skeleton-fixup2.mib \
                            $(XSL)/$(FIXUPREMOVEBLANKLINES)
	$(PERL)/perl.exe $(XSL)/$(FIXUPREMOVEBLANKLINES)    \
                     $(DST)/skeleton-fixup2.mib         \
                     > $(DST)/skeleton-fixup3.mib

# Fourth fixup: Rewrap the Description clauses, which XSL creates as
# one long string.  
$(DST)/skeleton-fixup4.mib : $(DST)/skeleton-fixup3.mib \
                            $(XSL)/$(FIXUPWRAPDESCRIPTIONS)
	$(PERL)/perl.exe $(XSL)/$(FIXUPWRAPDESCRIPTIONS)    \
                     $(DST)/skeleton-fixup3.mib         \
                     > $(DST)/skeleton-fixup4.mib

# NYI: Not Yet Implemented.
# Fifth fixup: Remove bogus blank lines where the UNITS clause 
# should be for properties that don't have units  
$(DST)/skeleton-fixup5.mib : $(DST)/skeleton-fixup4.mib \
                            $(XSL)/$(FIXUPREMOVEBLANKUNITS)
	$(PERL)/perl.exe $(XSL)/$(FIXUPREMOVEBLANKUNITS)    \
                     $(DST)/skeleton-fixup4.mib         \
                     > $(DST)/skeleton-fixup5.mib

#=======================================================
# C h e c k s 
#=======================================================
# Glance at the MIB to see if it looks okay.  
target_checkmib : target_checklongnames

target_checklongnames : $(DST)/skeleton-final-names-too-long.txt    \
                        $(XSL)/$(CHECKFINDLONGNAMES)
$(DST)/skeleton-final-names-too-long.txt :  $(DST)/skeleton-final.mib   \
                                            $(XSL)/$(CHECKFINDLONGNAMES)
	$(PERL)/perl.exe $(XSL)/$(CHECKFINDLONGNAMES)   \
	                 $(DST)/skeleton-final.mib      \
	                 > $(DST)/skeleton-final-names-too-long.txt




